pub struct NetworkEvents {
pub peers_connected: Vec<PeerId>,
pub peers_disconnected: Vec<PeerId>,
pub packets: Vec<(PeerId, Vec<u8>)>,
}Expand description
Per-frame network events, drained from the background network thread.
These vectors are populated once per frame by [NetworkHandle::poll()]
and auto-cleared at the start of the next poll cycle. This mirrors the
one-frame lifecycle of button press/release events.
Fields
peers_connected: Vec<PeerId>peers_disconnected: Vec<PeerId>packets: Vec<(PeerId, Vec<u8>)>Trait Implementations
Sourceimpl Clone for NetworkEvents
impl Clone for NetworkEvents
Sourcefn clone(&self) -> NetworkEvents
fn clone(&self) -> NetworkEvents
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NetworkEvents
impl Debug for NetworkEvents
Sourceimpl Default for NetworkEvents
impl Default for NetworkEvents
Sourcefn default() -> NetworkEvents
fn default() -> NetworkEvents
Returns the “default value” for a type. Read more